module aleta

! criao = 20 Ago 01;     ltima alterao = 28 Fev 02

! calcula o perfil de temperaturas (T)
! para aletas de seo reta uniforme cilndricas segundo
! solues analticas exatas e a condio de contorno desejada

! fonte das solues: Incropera e DeWitt (1998), 4a. ed.


USE MSFLIB

! *** variveis ***

implicit none

!-------------------------------------------------

CONTAINS


!-------------------------------------------------

  subroutine calculos ( cc, n, Tb, Ti, h, L, D, k, Tp )

    integer,intent(in) :: cc !  tipo de condio de contorno (adimensional)
    integer,intent(in) :: n  !  nmero de pontos a calcular a temperatura

    real*8,intent(in)  :: Tb !  temperatura da base da aleta (C)
    real*8,intent(in)  :: Ti !  temperatura do fluido (C)
    real*8,intent(in)  :: h  !  coeficiente de conveco (W/m2.C)
    real*8,intent(in)  :: L  !  comprimento da aleta (m)
    real*8,intent(in)  :: D  !  dimetro da aleta (m)
    real*8,intent(in)  :: k  !  condutividade trmica da aleta (W/m.C)
    real*8,intent(in)  :: Tp !  temperatura na ponta da aleta para cc=3

    real*8,dimension(:),allocatable :: T  ! temperatura em cada ponto da aleta (C)
    real*8,dimension(:),allocatable :: X  ! coordenada espacial (m)

    real*8 :: dx ! comprimento dos elementos da aleta (m)

    real*8  :: m,  Mg, pi, a1, a2, a3, a4
    real*8  :: q,  e,  na

    integer :: i ! nmero do ponto a calcular

    ! *** clculo de T(X) e q conforme cc escolhido

    pi = dacos(-1.0d0)
    m  = dsqrt(4 * h / ( k * D))
    Mg = dsqrt((pi**2)*(D**3)*h*k/4)*(Tb-Ti)
    dx = L / (n-1)
 
    allocate ( T(n), X(n) )

    do i = 1, n
       X(i) = (i-1)*dx
    end do

    select case (cc)

      ! cc = 1, conveco na ponta da aleta
      case (1)
        a1 = h/(m*k)
        a2 = dcosh(m*L) + a1*dsinh(m*L)
        do i = 1, n
           a3 = dcosh(m*(L-X(i))) + a1*dsinh(m*(L-X(i)))
           T(i) = Ti + (Tb-Ti)*a3/a2
        end do
        a4 = dsinh(m*L) + a1*dcosh(m*L)
        q  = Mg * a4 / a2

      ! cc = 2, ponta da aleta isolada
      case (2)
        do i = 1, n
           T(i) = Ti + (Tb-Ti) * dcosh(m*(L-X(i))) / dcosh(m*L)
        end do
        q  = Mg * dtanh(m*L)

      ! cc = 3, T prescrita na ponta da aleta = Tp
      case (3)
        a1 = (Tp-Ti)/(Tb-Ti)
        do i = 1, n
           a2 = a1*dsinh(m*X(i)) + dsinh(m*(L-X(i)))
           T(i) = Ti + (Tb-Ti)*a2/(dsinh(m*L))
        end do
        a3 = (dcosh(m*L) - a1)/dsinh(m*L)
        q  = Mg * a3

      ! cc = 4, aleta de comprimento infinito
      case (4)
        do i = 1, n
           T(i) = Ti + (Tb-Ti) * dexp(-m*X(i))
        end do
	    q  = Mg

    end select

    ! *** clculo de e, na

    e = 4 * q / (pi * (D**2) * h * (Tb-Ti))

    a1 = pi*D*L + pi*(D**2)/4
    na = q / (a1 * h * (Tb-Ti))

    ! *** sada dos resultados no arquivo de listagem ***

    open(10,file="listagem.txt")

    write(10,30) q, e, na*1.0d+2
    30 format(/,1pe22.9," = calor trocado pela aleta (W)",  &
             //,1pe22.9," = efetividade da aleta (adimensional)",  &
             //,1pe22.9," = eficincia da aleta (%)",  &
            ///,5x,"Campo de Temperaturas", &
             //,7x,"X (m)",17x,"T (C)",/)

    do i = 1, n
       write(10,40) X(i), T(i)
    end do
    40 format(2(1pe22.9))

    close(10)

    open(10,file="campo_T.dat")

    do i = 1, n
       write(10,40) X(i), T(i)
    end do

    close(10)

    deallocate ( T, X )

  end subroutine calculos


end module aleta
